@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "rbs-mode" "0.3.3"
+(define-package "rbs-mode" "20260203.1023"
   "A major mode for RBS."
   '((emacs "25.3"))
   :url "https://github.com/ybiquitous/rbs-mode"
